@@ -79,8 +79,27 @@ def generate_volume_weighted_high_low_vol(lookback_windows, vol_thresholds, up_t
                                 })
     return parameters
 
+def generate_slope_induced(lookback_windows, contravariants, lags, slope_columns, up_trend_thresholds,  low_trend_thresholds, display):
+    parameters = []
+    for slope_column in slope_columns:
+        for lookback_window in lookback_windows:
+            for contravariant in contravariants:
+                for lag in lags:
+                    for up_trend_threshold in up_trend_thresholds:
+                        for low_trend_threshold in low_trend_thresholds:
+                            if lag <= int(lookback_window/2):
+                                parameters.append({
+                                    'lookback_window':lookback_window,
+                                    'contravariant':contravariant,
+                                    'up_trend_threshold': up_trend_threshold,
+                                    'low_trend_threshold': low_trend_threshold,
+                                    'lag':lag,
+                                    'slope_column': slope_column,
+                                    'display' : display
+                                })
+    return parameters
 
-def generate_slope_induced(lookback_windows, contravariants, lags, slope_columns, display):
+def generate_slope_induced_cont(lookback_windows, contravariants, lags, slope_columns, display):
     parameters = []
     for slope_column in slope_columns:
         for lookback_window in lookback_windows:
