@@ -94,24 +94,7 @@ def alpha_16(data = None, contravariant = -1., lag = 5, **kwargs):
     result_df = result_df.rank(pct = True)
     return result_df.iloc[-1,0]
 
-def counting_candles(data= None, threshold = 1., contravariant = -1, **kwargs):
-    me_values = (data.close.diff() >= 0.).astype(float).value_counts()
-    try:
-        one_count = me_values[1.]
-    except KeyError:
-        one_count = 0
-    try:
-        zero_count = me_values[0.]
-    except KeyError:
-        zero_count = None
-    if zero_count is not None:
-        ratio = one_count/zero_count
-        if ratio >= threshold:
-            return -contravariant
-        else:
-            return contravariant
-    else :
-        return -contravariant
+
 
 
 def dd_threshold(data = None, threshold=1., contravariant = -1., **kwargs):
@@ -245,9 +228,44 @@ def volume_weighted_high_low_vol_cont(data = None,  contravariant = -1., lag = 2
 #
 
 
+def slope_induced(data = None, contravariant = -1., up_trend_threshold=0.8, low_trend_threshold=0.2, lag = 2, slope_column = 'high',**kwargs):
+    ## aggregating the volumes by lag
+    data.index = range(0,len(data))
+    all_indices = list(reversed(range(len(data) - 1, 0, -lag)))
+    data['aggregated_indice'] = np.nan
+    data['aggregated_indice'].loc[all_indices] = all_indices
+    data['aggregated_indice']= data['aggregated_indice'].fillna(method='bfill')
+    data['aggregated_indice'] = data['aggregated_indice'].astype(int)
+    volumefrom = data.groupby(['aggregated_indice'])['volumefrom'].agg('sum')
+    high = data.groupby(['aggregated_indice'])['high'].agg('max')
+    low = data.groupby(['aggregated_indice'])['low'].agg('min')
 
+    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom)
+    data['aggregated_high'] =  data['aggregated_indice'].map(high)
+    data['aggregated_low'] =  data['aggregated_indice'].map(low)
 
-def slope_induced(data = None, contravariant = -1., lag = 2, slope_column = 'high',**kwargs):
+    data = data[::-lag]
+    data = data.iloc[::-1]
+
+    data['hl'] = (data['aggregated_high'] - data['aggregated_low'])/data['aggregated_low']
+    data['volu_hi_low'] = data['aggregated_volume']*data['hl']
+
+    data['close_ret']=data['close'].pct_change()
+
+    data['volu_hi_low_pct_rank'] = data['volu_hi_low'].rank(pct=True)
+    data['close_ret_pct_rank'] = data['close_ret'].rank(pct=True)
+
+    trend_rank = data['close_ret_pct_rank'].iloc[-1]
+    #vol_rank = data['volu_hi_low_pct_rank'].iloc[-1]
+
+    if trend_rank > up_trend_threshold:
+        return contravariant
+    elif trend_rank < low_trend_threshold:
+        return -contravariant
+    else:
+        return np.nan
+
+def slope_induced_cont(data = None, contravariant = -1., lag = 2, slope_column = 'high',**kwargs):
     ## aggregating the volumes by lag
     data.index = range(0,len(data))
     all_indices = list(reversed(range(len(data) - 1, 0, -lag)))
@@ -287,3 +305,21 @@ def slope_induced(data = None, contravariant = -1., lag = 2, slope_column = 'hig
 
     return contravariant*signal
 
+def counting_candles(data= None, threshold = 1., contravariant = -1, **kwargs):
+    me_values = (data.close.diff() >= 0.).astype(float).value_counts()
+    try:
+        one_count = me_values[1.]
+    except KeyError:
+        one_count = 0
+    try:
+        zero_count = me_values[0.]
+    except KeyError:
+        zero_count = None
+    if zero_count is not None:
+        ratio = one_count/zero_count
+        if ratio >= threshold:
+            return -contravariant
+        else:
+            return contravariant
+    else :
+        return -contravariant
\ No newline at end of file
